@@ -36,5 +36,11 @@
 #ifndef GR_RPCSERVER_THRIFT
 /* #undef GR_RPCSERVER_THRIFT */
 #endif
+#ifndef GR_MPLIB_GMP
+#define GR_MPLIB_GMP
+#endif
+#ifndef GR_MPLIB_MPIR
+/* #undef GR_MPLIB_MPIR */
+#endif
 
 #endif /* GNURADIO_CONFIG_H */
